package VMOMI::HostPatchManagerIntegrityStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
